@@ -72,7 +72,7 @@ use namespace::autoclean;
 use utf8;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.3.3'; # VERSION
+our $VERSION = 'v0.3.4'; # VERSION
 
 use Dist::Zilla::Tester::DieHard 0.002;     # DieHard v0.001 rethrows modified exception.
 use File::Temp qw{ tempdir };
@@ -471,7 +471,7 @@ after run_test => sub {
     my ( $self ) = @_;
     my $tb = Test::Builder->new();
     if ( not $tb->is_passing and $self->_annotation ne '' ) {
-        ( my $annotation = $self->_annotation ) =~ s{^}{│ }gmx;
+        ( my $annotation = $self->_annotation ) =~ s{^}{| }gmx;
         $tb->diag( $annotation );
         $self->{ _annotation } = '';
     };
@@ -535,7 +535,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.3.3, released on 2015-09-27 17:10 UTC.
+Version v0.3.4, released on 2015-10-10 22:27 UTC.
 
 =head1 SYNOPSIS
 
